#ifndef LAST_H
#define LAST_H
#include <QtGui>
#include <QXmlStreamReader>
#include <QtXml>
#include <QDomDocument>
#include <QXmlStreamReader>
#include <QMap>
#include <QtNetwork>
#include "last/requests.h"
#include "last/utils.h"


class last: public QObject {
    Q_OBJECT
public :
        last(QString,QString);
        ~last();
        QString user;
        QString password;
        QString apikey;
        QString secret;
        QString sharedsecret;
        QString sessionkey;
        QString auth_token;
        QString token;
        QString sk;
        QString session_id ;
        QString playing_url;
        QString submission_url;
    public slots:
        void now(QStringList,int);
        void addTrack(QStringList,int);
    private slots:
        void authGetMobileSessionReply(QString data);
        void scrobblerHandshake();
        void scrobblerHandshakeReply(QString data);
        void scrobblerPlayingReply(QString data);


signals:
    void authGetMobileSessionData(QMap<QString, QString> reply);
};





#endif
